@@ -1,11 +1,30 @@
 import re
 import warnings
+from difflib import SequenceMatcher as SM
+from nltk.util import ngrams
+
+def fuzzy_match(needle, hay, flags=None, needle_length_window=0.2):
+    """Searches on the most similar string. 
+    Code adapted from: 
+    https://stackoverflow.com/questions/17740833/checking-fuzzy-approximate-substring-existing-in-a-longer-string-in-python/31433394#31433394
+    """
+    needle_length  = len(needle.split())
+    max_sim_val    = 0
+    max_sim_string = u""
+    for ngram in ngrams(hay.split(), needle_length + int(needle_length_window*needle_length)):
+        hay_ngram = u" ".join(ngram)
+        similarity = SM(None, hay_ngram, needle).ratio() 
+        if similarity > max_sim_val:
+            max_sim_val = similarity
+            max_sim_string = hay_ngram 
+    return re.search(max_sim_string, hay, flags=flags)
+
 def get_start_end_index(achievement, rel_string, case_insensitive=False):
     rel_string = rel_string.strip()
     if case_insensitive:
-        matched = re.search(rel_string, achievement, flags=re.IGNORECASE | re.MULTILINE)
+        matched = fuzzy_match(rel_string, achievement, flags=re.IGNORECASE | re.MULTILINE)
     else:
-        matched = re.search(rel_string, achievement)
+        matched = fuzzy_match(rel_string, achievement)
     if matched is None:
         warnings.warn(rel_string + "\nnot found in: \n" + achievement)
         return {"start_index": -1, "end_index": -1, "repl": rel_string}
